# README 

## Introduction
The DrugPrep algorithm prepares prescription data to give start and stop dates for each prescription, where only the start date, quantity and numeric daily dose is given. 

## Pre-requisites 

### Software 
DrugPrep currently exists as a collection of Stata do-files.  In order to run the do-files, you will need: 
* Stata 11 or higher
* The user written command tvc_split (included in the package tvc_merge, Mark Lunt, University of Manchester) 

#### Installing tvc_merge 
To install tvc_merge, you will need to type the following from within stata
```
net from http://personalpages.manchester.ac.uk/staff/mark.lunt
```
Follow the link to download and install the tvc_merge package.

### Data 
DrugPrep has been developed to process prescriptions data from the Clinical Practice Research Datalink (CPRD).  You will need a dataset containing the following variables for the drug types (prodcodes) you are interested in:  

Variable description	| Name in script | Name on CPRD |  Where located in CPRD
-----|-----------------|-----------|--------------
Patient identifier | patid | patid | Therapy file
Product identifier | prodcode | prodcode | Therapy file
Start date of prescription	| start | start |Therapy file
Quantity 	| qty | qty | Therapy file
Numeric daily dose | ndd | ndd |	Therapy file
Number of days of treatment prescribed	| numdays | numdays | Therapy file
Dose duration	| dose_duration | dose_duration | common_dosages file
Maximum and minimum length of prescriptions	| | NA | Not in CPRD: self-defined
Maximum and minimum numeric daily dose	|  max_ndd, min_ndd | NA | Not in CPRD: self-defined
Maximum and minimum quantity	|  max_qty, min_qty | NA | Not in CPRD: self-defined

## Scripts Structure 
```
───1_pre_drugprep
       1_pre_drugprep.do

───2_run_drugprep
       run_decs.do

───3_drugprep_scripts
       dec0_set_implausible_values.do
       dec1_implausible_qty.do
       dec2_missing_qty.do
       dec3_implausible_ndd.do
       dec4_missing_ndd.do
       dec5_clean_duration.do
       dec6_select_stop_date.do
       dec7_missing_stop_dates.do
       dec8_multiple_prescriptions_on_same_day_with_diff_stop_date.do
       dec9_overlapping_prescriptions.do
       dec10_gaps_between_prescriptions.do
```

### 1_pre_drugprep (CPRD specific)
*	Contains any scripts that prepare the raw therapy file for the prodcodes of interest, before it is run through the algorithm.
*	This is not essential to the running of the algorithm, it is more to highlight that the therapy file may need cleaning.
*	The scripts could remove duplicates, define time windows, clean particular variables etc., producing a 'cleaner' therapy file that is put through the algorithm.

### 2_run_drugprep
*	Contains 'run_decs.do' which is a 'master' do file that runs the individual DrugPrep do files.

### 3_drugprep_scripts
*	Contains the 10 individual decision node scripts (Decs1-10.do), plus:
  *	Dec0_set_implausible_values.do:	where implausible qty and ndd are defined using minimum and maximum quantity and numeric daily doses for each product code based on maximum and minimum length of prescriptions.

## run.do
*	This is the do file where you select your data preparation options and run the entire algorithm, creating one dataset of time varying drug exposure data.
*	This do file also outputs a log file 'RUN_DRUGPREP.log' that contains all the stata output during the running of the algorithm. This can be used to check if the algorithm has run correctly.

## Scripts Usage Instructions:
In order to run the scripts you need to do the following:

### run.do
1.	Define macros with file locations at the start of script.
2.	Define which option you want to use at each of the 10 decision nodes.

### 2_run_drugprep/run_decs.do
1.	Define the location of the file prepared in pre_drugprep scripts, which is to go into the algorithm. 
2.	Define the location where the file outputted from the algorithm is to be saved.

### 3_drugprep_scripts/dec0_set_implausible_values.do
1.	Define maximum and minimum quantities and numeric daily doses for all prodcodes.
Running run.do will run the algorithm.


## Output
The algorithm runs through by prodcode to allow extra granularity in the data. This means the decisions are made by prodcode and so the final file is a dataset of prescriptions prepared by prodcode.

This means that it is likely further prepare the data will be needed after the algorithm, for example to collapse down prescriptions of the same drug type but different prodcodes, or to add in rows where there are gaps between prescriptions, but this will be specific for your study. 


