* Copyright (c) Arthritis Research UK Centre for Epidemiology, University of Manchester (2016-2018)

global basedir 	C:/Work/GitHub/DrugPrep-master

global logdir   	$basedir/log
global savedir  	$basedir/save
global dodir    	$basedir/scripts
global datadir 		$basedir/data

use $datadir/pre_drugprep_in.dta, clear

// Making new format common_dosage file (2018 onwards) compatible.
// Only two variables have been renamed (textid now dosageid, text now dosage_text)
capture gen textid = dosageid
capture gen text = dosage_text

// prodcode 1 is a missing value: something was given,
// but what was not recorded
// On the other hand, textid is often recorded
// Get rid of prescriptions that appear to be identical
// Also drop if textid == 0 & another prescription for that date exists
// Note: new textid is a string. no textid==0

drop if prodcode == 1
   
duplicates drop
  
sort patid prodcode eventdate textid
capture by patid prodcode eventdate: drop if textid == 0 & textid[_n+1] > 0 & textid[_n+1] < .
capture by patid prodcode eventdate: drop if textid == "" & textid[_n+1] != ""

local num_presc = _N
notes: "Total prescriptions = `num_presc'"

gen double start = mdy(real(substr(eventdate,4,2)),real(substr(eventdate,1,2)), ///
			real(substr(eventdate,7,4)))

sort patid prodcode start textid
gen presc_id = _n
 
// Processed bnfcode, but clashes with string version in product
sort patid textid
capture merge m:1 textid using "$datadir/common_dosages", generate(_has_text)
capture merge m:1 dosageid using "$datadir/common_dosages", generate(_has_text)
drop if _has_text == 2

capture gen text = dosage_text

*recode qty/ndd==0 to missing
recode qty 0=.
recode ndd 0=.

sort patid prodcode date consid
qui compress

save "$datadir/pre_drugprep_out.dta", replace	
