* Copyright (c) Arthritis Research UK Centre for Epidemiology, University of Manchester (2016-2018)
*This do file sets thresholds of plausibilty for qty and ndd values
*by prodcode
*this needs to occur before the DrugPrep algorithm is run

*IMPLAUSIBILITY IS DEFINED AS WHAT THE BNFS +/- 10%

/*
   prodcode |      Freq.     Percent        Cum.
------------+-----------------------------------
        823 |    379,931       39.22       39.22
        508 |    158,383       16.35       55.56
        672 |    106,251       10.97       66.53
        380 |     76,341        7.88       74.41
        877 |     59,339        6.12       80.54
       5427 |     27,393        2.83       83.36
        571 |     25,291        2.61       85.97
       6934 |     20,367        2.10       88.08
       4971 |     15,244        1.57       89.65
       4978 |      9,933        1.03       90.67
       4946 |      9,340        0.96       91.64
       3267 |      9,302        0.96       92.60
        604 |      8,610        0.89       93.49
       2920 |      8,388        0.87       94.35
        643 |      6,872        0.71       95.06
       1566 |      5,927        0.61       95.67
	451 |      4,846        0.50       96.17
       8583 |      2,116        0.22       96.39
        422 |      1,699        0.18       96.57
       4231 |      1,645        0.17       96.74
      13428 |      1,640        0.17       96.91
       2837 |      1,568        0.16       97.07
       3329 |      1,496        0.15       97.22
       4470 |      1,427        0.15       97.37
       3934 |      1,418        0.15       97.52
      18424 |      1,327        0.14       97.65
        973 |      1,240        0.13       97.78
       3896 |      1,230        0.13       97.91
      17642 |      1,159        0.12       98.03
        972 |      1,088        0.11       98.14
       2838 |      1,027        0.11       98.25



                             productname |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
             Methotrexate 2.5mg tablets |    379,931       39.22       39.22
Sulfasalazine 500mg gastro-resistant ta |    158,383       16.35       55.56
       Hydroxychloroquine 200mg tablets |    106,251       10.97       66.53
 Salazopyrin EN-Tabs 500mg (Pfizer Ltd) |     76,341        7.88       74.41
              Methotrexate 10mg tablets |     59,339        6.12       80.54
            Sulfasalazine 500mg tablets |     27,393        2.83       83.36
              Azathioprine 50mg tablets |     25,291        2.61       85.97
               Leflunomide 20mg tablets |     20,367        2.10       88.08
               Leflunomide 10mg tablets |     15,244        1.57       89.65
 Salazopyrin 500mg tablets (Pfizer Ltd) |      9,933        1.03       90.67
       Plaquenil 200mg tablets (Sanofi) |      9,340        0.96       91.64
Myocrisin 50mg/0.5ml solution for injec |      9,302        0.96       92.60
            Penicillamine 250mg tablets |      8,610        0.89       93.49
             Sulfasalazine 500mg tablet |      8,388        0.87       94.35
            Penicillamine 125mg tablets |      6,872        0.71       95.06
Salazopyrin 500mg Tablet (Pharmacia Ltd |      5,927        0.61       95.67
	      Azathioprine 25mg tablets |      4,846        0.50       96.17
         Methotrexate 25mg/ml Injection |      2,116        0.22       96.39
    Chloroquine phosphate 250mg tablets |      1,699        0.18       96.57
Neoral 50mg capsules (Novartis Pharmace |      1,645        0.17       96.74
     Maxtrex 2.5mg tablets (Pfizer Ltd) |      1,640        0.17       96.91
              Ciclosporin 50mg capsules |      1,568        0.16       97.07
Myocrisin 20mg/0.5ml solution for injec |      1,496        0.15       97.22
Sodium aurothiomalate 50mg/0.5ml soluti |      1,427        0.15       97.37
                  Auranofin 3mg tablets |      1,418        0.15       97.52
       Methotrexate sodium 2.5mg Tablet |      1,327        0.14       97.65
Neoral 100mg capsules (Novartis Pharmac |      1,240        0.13       97.78
             Ciclosporin 100mg capsules |      1,230        0.13       97.91
            Arava 20mg tablets (Sanofi) |      1,159        0.12       98.03
Neoral 25mg capsules (Novartis Pharmace |      1,088        0.11       98.14
              Ciclosporin 25mg capsules |      1,027        0.11       98.25
*/




gen qty_max =.
label var qty_max "maximum plausible qty (based on BNF)"

gen qty_min =.
label var qty_min "minimun plausible qty (based on BNF)"

gen max_rec_ndd = .
label var max_rec_ndd "maximum plausible ndd"

gen min_rec_ndd = .
label var min_rec_ndd "minimum plausible ndd"


*gen a temp qty/ndd to have a quick look at durations.
gen temp_duration = qty / ndd
*I've decided to go for 2 months (56 days) for DMARDs: mean 41 days, median 28 days, 90% 60 days.
* I've decided to use the mimimum prescription for 1 week of medication


*823: Methotrexate 2.5mg tablets: weekly drug, maximum weekly dose is 20mg
*13428 Maxtrex 2.5mg tablets (Pfizer Ltd)
*18424 Methotrexate sodium 2.5mg Tablet
replace qty_max = (480 + (0.1*480)) if prodcode==823 | prodcode==13428 | prodcode==18424
replace max_rec_ndd = 1.2 if prodcode==823 | prodcode==13428 | prodcode==18424
replace qty_min = 2 if prodcode==823 | prodcode==13428 | prodcode==18424
replace min_rec_ndd = 0.1 if prodcode==823 | prodcode==13428 | prodcode==18424

*508: Sulfasalazine 500mg gastro-resistant tablets, max 8g per day
*380: Salazopyrin EN-Tabs 500mg (Pfizer Ltd) = sulfasalazine
*5427: Sulfasalazine 500mg tablets
*4978: Salazopyrin 500mg tablets (Pfizer Ltd)
*2920 Salazopyrin 500mg Tablet (Pharmacia Ltd 
*1566: Salazopyrin 500mg Tablet (Pharmacia Ltd
replace qty_max = (960 + (0.1*960)) if prodcode==508 | prodcode==380 | prodcode==5427 | prodcode==4978 | prodcode==2920 | prodcode==1566
replace max_rec_ndd = 8 if prodcode==508 | prodcode==380 | prodcode==5427 | prodcode==4978 | prodcode==2920 | prodcode==1566
replace qty_min = 7 if prodcode==508 | prodcode==380 | prodcode==5427 | prodcode==4978 | prodcode==2920 | prodcode==1566
replace min_rec_ndd = 1 if prodcode==508 | prodcode==380 | prodcode==5427 | prodcode==4978 | prodcode==2920 | prodcode==1566

*672: Hydroxychloroquine 200mg tablets, max 6.5mg/kg ideal body weight (I am using 100kg)
replace qty_max = (240 + (0.1*240)) if prodcode==672
replace max_rec_ndd = 4 if prodcode==672
replace qty_min = 7 if prodcode==672
replace min_rec_ndd = 1 if prodcode==672

*877: Methotrexate 10mg tablets
replace qty_max = (240 + (0.1*240)) if prodcode==877
replace max_rec_ndd = 0.5 if prodcode==877
replace qty_min = 4 if prodcode==877
replace min_rec_ndd = 0.1 if prodcode==877

*571: Azathioprine 50mg tablets, usually 3mg/kg used 100kg as max
replace qty_max = (360 + (0.1*360)) if prodcode==571
replace max_rec_ndd = 9 if prodcode==571
replace qty_min = 2 if prodcode==571
replace min_rec_ndd = 1 if prodcode==571

*6934: Leflunomide 20mg tablets, used 40mg as max dose
*17642  Arava 20mg tablets (Sanofi)
replace qty_max = (120 + (0.1*120)) if prodcode==6934 | prodcode==17642
replace max_rec_ndd = 2 if prodcode==6934 | prodcode==17642
replace qty_min = 7 if prodcode==6934 | prodcode==17642
replace min_rec_ndd = 1 if prodcode==6934 | prodcode==17642

*4971 Leflunomide 10mg tablets, used 40mg as max dose
replace qty_max = (240 + (0.1*240)) if prodcode==4971
replace max_rec_ndd = 4 if prodcode==4971
replace qty_min = 14 if prodcode==4971
replace min_rec_ndd = 1 if prodcode==4971

*4946: Plaquenil 200mg tablets (Sanofi) 
replace qty_max = (240 + (0.1*240)) if prodcode==4946
replace max_rec_ndd = 4 if prodcode==4946
replace qty_min = 7 if prodcode==4946
replace min_rec_ndd = 1 if prodcode==4946

*3267 Myocrisin 50mg/0.5ml solution for injec (sodium aurothiomalate)
*4470 Sodium aurothiomalate 50mg/0.5ml soluti
replace qty_max = (20 + (0.1*20)) if prodcode==3267 | prodcode==4470
replace max_rec_ndd = 0.143 if prodcode==3267 | prodcode==4470
replace qty_min = 1 if prodcode==3267 | prodcode==4470
replace min_rec_ndd = 0.033 if prodcode==3267 | prodcode==4470

*643 Penicillamine 125mg tablets
replace qty_max = (720 + (0.1*720)) if prodcode==643
replace max_rec_ndd = 18 if prodcode==643
replace qty_min = 7 if prodcode==643
replace min_rec_ndd = 1 if prodcode==643

*451 Azathioprine 25mg tablets
replace qty_max = (720 + (0.1*720)) if prodcode==451
replace max_rec_ndd = 18 if prodcode==451
replace qty_min = 4 if prodcode==451
replace min_rec_ndd = 2 if prodcode==451

*8583 Methotrexate 25mg/ml Injection
replace qty_max = (360 + (0.1*360)) if prodcode==8583
replace max_rec_ndd = 9 if prodcode==8583
replace qty_min = 7 if prodcode==8583
replace min_rec_ndd = 1 if prodcode==8583

*422 Chloroquine phosphate 250mg tablets
replace qty_max = (60 + (0.1*60)) if prodcode==422
replace max_rec_ndd = 2 if prodcode==422
replace qty_min = 7 if prodcode==422
replace min_rec_ndd = 1 if prodcode==422

*4231 Neoral 50mg capsules (Novartis Pharmace
*2837 Ciclosporin 50mg capsules
replace qty_max = (480 + (0.1*480)) if prodcode==4231 | prodcode==2837
replace max_rec_ndd = 8 if prodcode==4231 | prodcode==2837
replace qty_min = 7 if prodcode==4231 | prodcode==2837
replace min_rec_ndd = 1 if prodcode==4231 | prodcode==2837

*13428 Maxtrex 2.5mg tablets (Pfizer Ltd)
replace qty_max = (360 + (0.1*360)) if prodcode==13428
replace max_rec_ndd = 9 if prodcode==13428
replace qty_min = 7 if prodcode==13428
replace min_rec_ndd = 1 if prodcode==13428

*3329 Myocrisin 20mg/0.5ml solution for injec (sodium aurothiomalate)
replace qty_max = (40 + (0.1*40)) if prodcode==3329
replace max_rec_ndd = 0.143 if prodcode==3329
replace qty_min = 1 if prodcode==3329
replace min_rec_ndd = 0.033 if prodcode==3329

*3934 Auranofin 3mg tablets
replace qty_max = (180 + (0.1*180)) if prodcode==3934
replace max_rec_ndd = 3 if prodcode==3934
replace qty_min = 7 if prodcode==3934
replace min_rec_ndd = 1 if prodcode==3934

*973 Neoral 100mg capsules (Novartis Pharmac
* 3896 Ciclosporin 100mg capsules
replace qty_max = (240 + (0.1*240)) if prodcode==973 | prodcode==3896
replace max_rec_ndd = 6 if prodcode==973 | prodcode==3896
replace qty_min = 7 if prodcode==973 | prodcode==3896
replace min_rec_ndd = 1 if prodcode==973 | prodcode==3896

*972 Neoral 25mg capsules (Novartis Pharmace
*2838 Ciclosporin 25mg capsules
replace qty_max = (360 + (0.1*360)) if prodcode==972 | prodcode==2838
replace max_rec_ndd = 8 if prodcode==972 | prodcode==2838
replace qty_min = 7 if prodcode==972 | prodcode==2838
replace min_rec_ndd = 1 if prodcode==972 | prodcode==2838

* Oral solutions as these qty and ndd different to tablets
*7497 Sulfasalazine 250mg/5ml oral solution
*11767 Sulfasalazine 250mg/5ml oral suspension
*17880 Salazopyrin 250mg/5ml Liquid (Pharmacia
*14054 Salazopyrin 250mg/5ml oral suspension (P
replace qty_max = 5000 if prodcode==7497 | prodcode==11767 | prodcode==17880 | prodcode==14054
replace max_rec_ndd = 70 if prodcode==7497 | prodcode==11767 | prodcode==17880 | prodcode==14054
replace qty_min = 1 if prodcode==7497 | prodcode==11767 | prodcode==17880 | prodcode==14054
replace min_rec_ndd = 1 if prodcode==7497 | prodcode==11767 | prodcode==17880 | prodcode==14054

*and now for the remainder
tab qty if qty_max==.
tab ndd if max_rec_ndd==.

replace qty_max = 1000 if qty_max==.
replace max_rec_ndd = 80 if max_rec_ndd==.
replace qty_min = 1 if qty_min==.
replace min_rec_ndd = 0.018 if min_rec_ndd==.

drop temp_duration
