	// Copyright (c) Arthritis Research UK Centre for Epidemiology, University of Manchester (2016-2018)
	// This do file handles decision 1 of the DrugPrep algorithm: 
 
  // Handle implausible qty (total number of things prescribed)
  // options are  1a  use implausible value
  //              1b  set to missing
  //              1c1  set to mean for individual's prescriptions for that drug
  //              1c2  set to mean for practice's prescriptions for that drug
  //              1c3  set to mean for populations's prescriptions for that drug
  //              1d1  set to median for individual's prescriptions for that drug
  //              1d2  set to median for practice's prescriptions for that drug
  //              1d3  set to median for population's prescriptions for that drug
  //              1e1  set to mode for individual's prescriptions for that drug
  //              1e2  set to mode for practice's prescriptions for that drug
  //              1e3  set to mode for population's prescriptions for that drug
  //              1f1  use value of individual's next prescription
  //              1f2  use value of practice's next prescription
  //              1f3  use value of population's next prescription
  //              1g1  use value of individual's previous prescription
  //              1g2  use value of practice's previous prescription  
  //              1g3  use value of population's previous prescription
 
 
  // Maintained by Ruth Costello, 2016-08-19

  args dec1
  local mainopt = substr("`dec1'", 1, 2)
  local subopt = substr("`dec1'", 3, 1)

  if "`subopt'" == "1" {
    local sorter patid
  }
  else if "`subopt'" == "2" {
    local sorter pracid
  }
  else if "`subopt'" == "3" {
    local sorter 
  }
  
  gen implausible = (qty > qty_max | qty < qty_min)  & qty < .
    
  if "`dec1'" == "1a" {
    // do nothing 
  }
  else if "`dec1'" == "1b" {
    replace qty = . if implausible==1
  }
  else if "`mainopt'" == "1c" {
    sort `sorter' prodcode implausible
    by `sorter' prodcode: egen mean_qty = mean(qty) if implausible == 0
    by `sorter' prodcode: replace mean_qty = mean_qty[_n-1] if mean_qty == .
    replace qty = mean_qty if implausible==1
  }
  else if "`mainopt'" == "1d" {
    sort `sorter' prodcode implausible
    by `sorter' prodcode: egen mean_qty = median(qty) if implausible == 0
    by `sorter' prodcode: replace mean_qty = mean_qty[_n-1] if mean_qty == .
    replace qty = mean_qty if implausible==1
  }
  else if "`mainopt'" == "1e" {
    sort `sorter' prodcode implausible
    by `sorter' prodcode: egen mean_qty = mode(qty) if implausible == 0, maxmode
    by `sorter' prodcode: replace mean_qty = mean_qty[_n-1] if mean_qty == .
    replace qty = mean_qty if implausible==1
  }
  else if "`mainopt'" == "1f" {
    sort `sorter' prodcode date presc_id
    by `sorter' prodcode: replace qty = qty[_n-1] if implausible==1 & ///
				qty[_n-1] >= qty_min & qty[_n-1] <= qty_max
    replace implausible = (qty > qty_max | qty < qty_min) & qty != .
    replace qty = . if implausible == 1
  }
  else if "`mainopt'" == "1g" {
    gsort `sorter' prodcode -date presc_id
    by `sorter' prodcode: replace qty = qty[_n-1] if implausible==1 & ///
				qty[_n-1] >= qty_min & qty[_n-1] <= qty_max
    replace implausible = (qty > qty_max | qty < qty_min) & qty != .
    replace qty = . if implausible == 1
  }
  
  capture drop mean_qty
  drop implausible

  
  
  
