  // Copyright (c) Arthritis Research UK Centre for Epidemiology, University of Manchester (2016-2018)
  // This do file handles decision 3 of the DrugPrep algorithm: 
 

  // Handle implausible ndd (number of things taken per day)
  // options are  3a  use implausible value
  //              3b  set to missing
  //              3c1  set to mean for individual's prescriptions for that drug
  //              3c2  set to mean for practice's prescriptions for that drug
  //              3c3  set to mean for populations's prescriptions for that drug
  //              3d1  set to median for individual's prescriptions for that drug
  //              3d2  set to median for practice's prescriptions for that drug
  //              3d3  set to median for population's prescriptions for that drug
  //              3e1  set to mode for individual's prescriptions for that drug
  //              3e2  set to mode for practice's prescriptions for that drug
  //              3e3  set to mode for population's prescriptions for that drug
  //              3f1  use value of individual's next prescription
  //              3f2  use value of practice's next prescription
  //              3f3  use value of population's next prescription
  //              3g1  use value of individual's previous prescription
  //              3g2  use value of practice's previous prescription  
  //              3g3  use value of population's previous prescription
 
  // Maintained by Ruth Costello, 2016-08-19

  args dec3 
  local mainopt = substr("`dec3'", 1, 2)
  local subopt = substr("`dec3'", 3, 1)

  if "`subopt'" == "1" {
    local sorter patid
  }
  else if "`subopt'" == "2" {
    local sorter pracid
  }
  else if "`subopt'" == "3" {
    local sorter 
  }


  gen ndd_imp = (ndd > max_rec_ndd | ndd < min_rec_ndd) & ndd != .
	
	
	if "`dec3'" == "3a" {
		// do nothing 
	}
	else if "`dec3'" == "3b" {
		replace ndd = . if ndd_imp==1
	}
  else if "`mainopt'" == "3c" {
    sort `sorter' prodcode ndd_imp
    by `sorter' prodcode: egen mean_ndd = mean(ndd) if ndd_imp == 0
    by `sorter' prodcode: replace mean_ndd = mean_ndd[_n-1] if mean_ndd == .
    replace ndd = mean_ndd if ndd_imp==1
  }
  else if "`mainopt'" == "3d" {
    sort `sorter' prodcode ndd_imp
    by `sorter' prodcode: egen mean_ndd = median(ndd) if ndd_imp == 0
    by `sorter' prodcode: replace mean_ndd = mean_ndd[_n-1] if mean_ndd == .
    replace ndd = mean_ndd if ndd_imp==1
  }
  else if "`mainopt'" == "3e" {
    sort `sorter' prodcode ndd_imp
    by `sorter' prodcode: egen mean_ndd = mode(ndd) if ndd_imp == 0, maxmode
    by `sorter' prodcode: replace mean_ndd = mean_ndd[_n-1] if mean_ndd == .
    replace ndd = mean_ndd if ndd_imp==1
  }
  else if "`mainopt'" == "3f" {
    sort `sorter' prodcode date presc_id
    by `sorter' prodcode: replace ndd = ndd[_n-1] if ndd_imp==1
    replace ndd_imp = (ndd > max_rec_ndd | ndd < min_rec_ndd) & ndd != .
    replace ndd = . if ndd_imp == 1
  }
  else if "`mainopt'" == "3g" {
    gsort `sorter' prodcode -date presc_id
    by `sorter' prodcode: replace ndd = ndd[_n-1] if ndd_imp==1
    replace ndd_imp = (ndd > max_rec_ndd | ndd < min_rec_ndd) & ndd != .
    replace ndd = . if ndd_imp == 1
  }

  capture drop mean_ndd
  drop ndd_imp

  
