* Copyright (c) Arthritis Research UK Centre for Epidemiology, University of Manchester (2016-2018)
*This do file handles decision 5 of the DrugPrep algorithm: 
 
// Clean durations that are longer than clinically plausible
// options are	5a	leave duration as it is
//		5b_6	set to missing if > 6 months
//		5b_12	set to missing if > 12 months
//		5b_24	set to missing if > 24 months
//		5c_6	set to 6 months if > 6 months
//		5c_12	set to 12 months if > 12 months
//		5c_24	set to 24 months if > 24 months
 

// Maintained by Ruth Costello, 2016-08-19

args dec5

gen new_duration = floor(qty/ndd)
label variable new_duration "Duration of this prescription calculated from ndd and qty"

	// remove implausible durations
	if "`dec5'" == "5a" {
		local max_duration = .
	}
	else if (("`dec5'" == "5b_6" ) | ("`dec5'" == "5c_6")) {
		local max_duration = 183
	}
	else if (("`dec5'" == "5b_12") | ("`dec5'" == "5c_12")) {
		local max_duration = 365
	}
	else if (("`dec5'" == "5b_24") | ("`dec5'" == "5c_24")) {
		local max_duration = 730
	}

	// should include dose_duration in varlist below ?
	// yes
	if "`dec5'" == "5b_6" | "`dec5'" == "5b_12" | "`dec5'" == "5b_24" {
		foreach var of varlist new_duration numdays dose_duration {
			replace `var' = . if `var' > `max_duration'
		}	
	}
	if "`dec5'" == "5c_6" | "`dec5'" == "5c_12" | "`dec5'" == "5c_24" {
		foreach var of varlist new_duration numdays dose_duration {
			replace `var' = `max_duration' if `var' > `max_duration' & `var' < .
		}	
	}

noi di as text "The variable " as result "new_duration" as text " has just been created."

		
		
		
		
