* Copyright (c) Arthritis Research UK Centre for Epidemiology, University of Manchester (2016-2018)
*This do file handles decision 6 of the DrugPrep algorithm: 
 
// Select which stop date to use
// options are	6a	stop1 (start + numdays)
//		6b	stop2 (start + dose_duration)
//		6c	stop3 (start + qty/ndd)
//			If only one stop available, use it
//			if two available and equal, use that date
//			if two available and unequal (but within x days), use mean
//			if three available and unequal, use mean of closest 2 if within x days
//				6d_15	x = 15
//				6d_30	x = 30
//				6d_60	x = 60
//				6d_90	x = 90
//				6e 	x = something very big, like 9,999,999 


// Maintained by Ruth Costello, 2016-08-19

args dec6

	// CPRD use 0 as a missing value. Fix that.
	replace numdays       = .a if numdays == 0
	replace dose_duration = .a if dose_duration == 0 
	replace new_duration  = .a if new_duration == 0
	
	// Create the various stop variables
	gen stop1 = start + numdays
	gen stop2 = start + dose_duration
	gen stop3 = start + new_duration

	// Decision 6: how to define the end of the current prescription
	if "`dec6'" == "6a" {
		gen double real_stop = stop1
	}
	else if "`dec6'" == "6b" {
		gen double real_stop = stop2
	}
	else if "`dec6'" == "6c" {
		gen double real_stop = stop3
	}
	else {
		gen double real_stop = .
		if "`dec6'" == "6d_15" {
			local max_diff = 15
		}
		else if "`dec6'" == "6d_30" {
			local max_diff = 30
		}
		else if "`dec6'" == "6d_60" {
			local max_diff = 60
		}
		else if "`dec6'" == "6d_90" {
			local max_diff = 90
		}
		else if "`dec6'" == "6e" {
			local max_diff = 9999999
		}
//		noi di in red "`max_diff'"
		egen num_stops = rownonmiss(stop1 stop2 stop3)
		tab num_stops
		gen diff12 = abs(stop1 - stop2)
		gen diff23 = abs(stop2 - stop3)
		gen diff13 = abs(stop3 - stop1)
		replace real_stop = stop1 if num_stops == 1 & stop1 < .
		replace real_stop = stop2 if num_stops == 1 & stop2 < .
		replace real_stop = stop3 if num_stops == 1 & stop3 < .
		gen mean_stop = floor((stop1 + stop2)/2) if stop3 >= . & num_stops == 2
		gen stop_diff = diff12 if stop3 >= . & num_stops == 2
		replace mean_stop = floor((stop1 + stop3)/2) if stop2 >= . & num_stops == 2
		replace stop_diff = diff13 if stop2 >= . & num_stops == 2
		replace mean_stop = floor((stop2 + stop3)/2) if stop1 >= . & num_stops == 2
		replace stop_diff = diff23 if stop1 >= . & num_stops == 2
		replace real_stop = mean_stop if stop_diff <= `max_diff'
		
		egen min_diff = rowmin(diff12 diff13 diff23) if num_stops ==  3
		gen diff_drop = 1 if min_diff == diff23 & num_stops == 3
		replace diff_drop = 2 if diff_drop == . & min_diff == diff13
		replace diff_drop = 3 if diff_drop == . & min_diff == diff12
		replace mean_stop = floor((stop1 + stop2)/2) if diff_drop == 3 & num_stops == 3
		replace stop_diff = diff12 if diff_drop == 3 & num_stops == 3
		replace mean_stop = floor((stop1 + stop3)/2) if diff_drop == 2 & num_stops == 3
		replace stop_diff = diff13 if diff_drop == 2 & num_stops == 3
		replace mean_stop = floor((stop2 + stop3)/2) if diff_drop == 1 & num_stops == 3
		replace stop_diff = diff23 if diff_drop == 1 & num_stops == 3
		replace real_stop = mean_stop if stop_diff <= `max_diff'		

		drop mean_stop num_stops diff12 diff13 diff23 stop_diff min_diff diff_drop
	}
	
	foreach num of numlist 1/3 {
		gen dur`num' = stop`num' - start
	}

label variable real_stop "Stop date for this prescription to be used for subsequent analysis"
label variable dur1 "Duration of exposure for this prescription calculated from numdays"
label variable dur2 "Duration of exposure for this prescription calculated from dose_duration"
label variable dur3 "Duration of exposure for this prescription calculated from ndd and qty"

drop stop1 stop2 stop3

gen real_duration = real_stop - start
label variable real_duration "Duration of exposure for this prescription to be used for subsequent analysis"

noi di as text "The variables " as result "real_stop" as text ", " as result "real_duration" as text ", " as result "dur1" ///
       as text ", " as result "dur2" as text " and " as result "dur3" as text " have just been created."
