// Copyright (c) Arthritis Research UK Centre for Epidemiology, University of Manchester (2016-2018)
// This do file handles decision 8 of the DrugPrep algorithm: 
 
// Handle multiple prescriptions for same product on same day
// will always drop if textid == 0 and there is another, non-zero textid
// options are	8a	Do nothing: implicitly sum doses as in dec9 below
//		8b	use mean ndd and mean length
//		8c	choose prescription with smallest ndd
//		8d	choose prescription with largest ndd
//		8e	choose shortest prescription
//		8f	choose longest prescription
// 		8g	sum durations
 
// Maintained by Ruth Costello, 2016-08-19

args dec8

// Decision 8: Which stop date to use if two records have same start date and prodcode
// but different stop dates

	sort patid prodcode start real_stop
	by patid prodcode start: egen stop_sd = sd(real_stop)

	if "`dec8'" == "8a" {
		// Do nothing: keep all simultaneous prescriptions
	}
	else if "`dec8'" == "8b" {
		// use mean ndd and mean length
		by patid prodcode start: egen mean_stop = mean(real_stop)
		by patid prodcode start: egen mean_ndd  = mean(ndd)
		by patid prodcode start: drop if _n > 1
		// is order unique: other variables may differ if not
		replace real_stop = floor(mean_stop) if stop_sd < .
		replace ndd       = mean_ndd  if stop_sd < .
		drop mean_stop mean_ndd
	}
	else if "`dec8'" == "8c" {
		// use prescription with smallest ndd
		by patid prodcode start: egen min_ndd = min(ndd)
		drop if stop_sd < . & ndd != min_ndd
		by patid prodcode start: drop if _n > 1
		drop min_ndd
	}
	else if "`dec8'" == "8d" {
		// use prescription with largest ndd
		by patid prodcode start: egen max_ndd = max(ndd)
		drop if stop_sd < . & ndd != max_ndd
		by patid prodcode start: drop if _n > 1
		drop max_ndd
	}
	else if "`dec8'" == "8e" {
		// use shortest prescription
		by patid prodcode start: egen min_stop = min(real_stop)
		drop if stop_sd > . & real_stop != min_stop
		by patid prodcode start: drop if _n > 1
		drop min_stop
	}
	else if "`dec8'" == "8f" {
		// use longest prescription
		by patid prodcode start: egen max_stop = max(real_stop)
		drop if stop_sd < . & real_stop != max_stop
    sort patid prodcode start presc_id
		by patid prodcode start: drop if _n > 1
		drop max_stop
	}
	else if "`dec8'" == "8g" {
		// sum durations
		by patid prodcode start: egen sum_duration=sum(real_duration)
		by patid prodcode start: replace real_stop = start + sum_duration if stop_sd < .
		drop sum_duration
		by patid prodcode start: drop if _n > 1 
	}
	

drop stop_sd





	
